Title: [119031] branches/safari-536-branch/Source/WebCore
Revision
119031
Author
[email protected]
Date
2012-05-30 20:12:49 -0700 (Wed, 30 May 2012)

Log Message

Merged r118087 -> <rdar://problem/11497837>

Modified Paths

Diff

Modified: branches/safari-536-branch/Source/WebCore/ChangeLog (119030 => 119031)


--- branches/safari-536-branch/Source/WebCore/ChangeLog	2012-05-31 03:05:34 UTC (rev 119030)
+++ branches/safari-536-branch/Source/WebCore/ChangeLog	2012-05-31 03:12:49 UTC (rev 119031)
@@ -1,5 +1,26 @@
 2012-05-30  Lucas Forschler  <[email protected]>
 
+    Merge 118087
+
+    2012-05-22  Jer Noble  <[email protected]>
+
+            REGRESSION (r98359): Video does not render on http://panic.com/dietcoda/
+            https://bugs.webkit.org/show_bug.cgi?id=87171
+
+            Reviewed by Maciej Stachowiak.
+
+            No new tests; behavior is very timing specific and only occurs on a subset of all platforms.
+
+            Instead of calling prepareForRendering() from metadataLoaded(), which may fail and cause subsequent
+            calls to prepareForRendering() to short circuit, call createVideoLayer() directly, which achieves
+            the original goals of the fix for http://webkit.org/b/70448, but without breaking subsequent calls
+            to prepareForRendering() if called at the wrong time.
+
+            * platform/graphics/avfoundation/MediaPlayerPrivateAVFoundation.cpp:
+            (WebCore::MediaPlayerPrivateAVFoundation::metadataLoaded):
+
+2012-05-30  Lucas Forschler  <[email protected]>
+
     Merge 116319
 
     2012-05-07  Nat Duca  <[email protected]>

Modified: branches/safari-536-branch/Source/WebCore/platform/graphics/avfoundation/MediaPlayerPrivateAVFoundation.cpp (119030 => 119031)


--- branches/safari-536-branch/Source/WebCore/platform/graphics/avfoundation/MediaPlayerPrivateAVFoundation.cpp	2012-05-31 03:05:34 UTC (rev 119030)
+++ branches/safari-536-branch/Source/WebCore/platform/graphics/avfoundation/MediaPlayerPrivateAVFoundation.cpp	2012-05-31 03:12:49 UTC (rev 119031)
@@ -531,11 +531,13 @@
     m_loadingMetadata = false;
     tracksChanged();
 
+#if USE(ACCELERATED_COMPOSITING)
     // AVFoundation will not return true for firstVideoFrameAvailable until
     // an AVPlayerLayer has been added to the AVPlayerItem, so call prepareForRendering()
     // here to trigger allocation of a AVPlayerLayer.
     if (m_cachedHasVideo)
-        prepareForRendering();
+        createVideoLayer();
+#endif
 }
 
 void MediaPlayerPrivateAVFoundation::rateChanged()
@@ -531,11 +531,13 @@
     // AVFoundation will not return true for firstVideoFrameAvailable until
-    // an AVPlayerLayer has been added to the AVPlayerItem, so call prepareForRendering()
+    // an AVPlayerLayer has been added to the AVPlayerItem, so call createVideoLayer()
     // here to trigger allocation of a AVPlayerLayer.
     if (m_cachedHasVideo)
_______________________________________________
webkit-changes mailing list
[email protected]
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes

Reply via email to